"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import stackl_client
from stackl_client.model.host_target import HostTarget


class TestHostTarget(unittest.TestCase):
    """HostTarget unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHostTarget(self):
        """Test HostTarget"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HostTarget()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from stackl_client.api_client import ApiClient, Endpoint as _Endpoint
from stackl_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from stackl_client.model.http_validation_error import HTTPValidationError
from stackl_client.model.infrastructure_base_document import InfrastructureBaseDocument


class InfrastructureBaseApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __delete_infrastructure_base(
            self,
            infrastructure_base_type,
            infrastructure_base_name,
            **kwargs
        ):
            """Delete Infrastructure Base  # noqa: E501

            Delete an infrastructure base document by name and type Type is environment, location or zone  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_infrastructure_base(infrastructure_base_type, infrastructure_base_name, async_req=True)
            >>> result = thread.get()

            Args:
                infrastructure_base_type (str):
                infrastructure_base_name (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                bool, date, datetime, dict, float, int, list, str, none_type
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['infrastructure_base_type'] = \
                infrastructure_base_type
            kwargs['infrastructure_base_name'] = \
                infrastructure_base_name
            return self.call_with_http_info(**kwargs)

        self.delete_infrastructure_base = _Endpoint(
            settings={
                'response_type': (bool, date, datetime, dict, float, int, list, str, none_type,),
                'auth': [],
                'endpoint_path': '/infrastructure_base/{infrastructure_base_type}/{infrastructure_base_name}',
                'operation_id': 'delete_infrastructure_base',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'infrastructure_base_type',
                    'infrastructure_base_name',
                ],
                'required': [
                    'infrastructure_base_type',
                    'infrastructure_base_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'infrastructure_base_type':
                        (str,),
                    'infrastructure_base_name':
                        (str,),
                },
                'attribute_map': {
                    'infrastructure_base_type': 'infrastructure_base_type',
                    'infrastructure_base_name': 'infrastructure_base_name',
                },
                'location_map': {
                    'infrastructure_base_type': 'path',
                    'infrastructure_base_name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_infrastructure_base
        )

        def __get_infrastructure_base_by_type(
            self,
            infrastructure_base_type,
            **kwargs
        ):
            """Get Infrastructure Base By Type  # noqa: E501

            Returns a specific infrastructure_base document with a type and name  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_infrastructure_base_by_type(infrastructure_base_type, async_req=True)
            >>> result = thread.get()

            Args:
                infrastructure_base_type (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                [InfrastructureBaseDocument]
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['infrastructure_base_type'] = \
                infrastructure_base_type
            return self.call_with_http_info(**kwargs)

        self.get_infrastructure_base_by_type = _Endpoint(
            settings={
                'response_type': ([InfrastructureBaseDocument],),
                'auth': [],
                'endpoint_path': '/infrastructure_base/{infrastructure_base_type}',
                'operation_id': 'get_infrastructure_base_by_type',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'infrastructure_base_type',
                ],
                'required': [
                    'infrastructure_base_type',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'infrastructure_base_type':
                        (str,),
                },
                'attribute_map': {
                    'infrastructure_base_type': 'infrastructure_base_type',
                },
                'location_map': {
                    'infrastructure_base_type': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_infrastructure_base_by_type
        )

        def __get_infrastructure_base_by_type_and_name(
            self,
            infrastructure_base_type,
            infrastructure_base_name,
            **kwargs
        ):
            """Get Infrastructure Base By Type And Name  # noqa: E501

            Returns a specific infrastructure_base document with a type and name  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_infrastructure_base_by_type_and_name(infrastructure_base_type, infrastructure_base_name, async_req=True)
            >>> result = thread.get()

            Args:
                infrastructure_base_type (str):
                infrastructure_base_name (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                InfrastructureBaseDocument
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['infrastructure_base_type'] = \
                infrastructure_base_type
            kwargs['infrastructure_base_name'] = \
                infrastructure_base_name
            return self.call_with_http_info(**kwargs)

        self.get_infrastructure_base_by_type_and_name = _Endpoint(
            settings={
                'response_type': (InfrastructureBaseDocument,),
                'auth': [],
                'endpoint_path': '/infrastructure_base/{infrastructure_base_type}/{infrastructure_base_name}',
                'operation_id': 'get_infrastructure_base_by_type_and_name',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'infrastructure_base_type',
                    'infrastructure_base_name',
                ],
                'required': [
                    'infrastructure_base_type',
                    'infrastructure_base_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'infrastructure_base_type':
                        (str,),
                    'infrastructure_base_name':
                        (str,),
                },
                'attribute_map': {
                    'infrastructure_base_type': 'infrastructure_base_type',
                    'infrastructure_base_name': 'infrastructure_base_name',
                },
                'location_map': {
                    'infrastructure_base_type': 'path',
                    'infrastructure_base_name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_infrastructure_base_by_type_and_name
        )

        def __post_infrastructure_base(
            self,
            infrastructure_base_document,
            **kwargs
        ):
            """Post Infrastructure Base  # noqa: E501

            Create the infrastructure_base document with a specific type and an optional name given in the payload  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_infrastructure_base(infrastructure_base_document, async_req=True)
            >>> result = thread.get()

            Args:
                infrastructure_base_document (InfrastructureBaseDocument):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                InfrastructureBaseDocument
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['infrastructure_base_document'] = \
                infrastructure_base_document
            return self.call_with_http_info(**kwargs)

        self.post_infrastructure_base = _Endpoint(
            settings={
                'response_type': (InfrastructureBaseDocument,),
                'auth': [],
                'endpoint_path': '/infrastructure_base',
                'operation_id': 'post_infrastructure_base',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'infrastructure_base_document',
                ],
                'required': [
                    'infrastructure_base_document',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'infrastructure_base_document':
                        (InfrastructureBaseDocument,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'infrastructure_base_document': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__post_infrastructure_base
        )

        def __put_infrastructure_base(
            self,
            infrastructure_base_document,
            **kwargs
        ):
            """Put Infrastructure Base  # noqa: E501

            Updates the infrastructure_base document with a specific type and an optional name given in the payload  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.put_infrastructure_base(infrastructure_base_document, async_req=True)
            >>> result = thread.get()

            Args:
                infrastructure_base_document (InfrastructureBaseDocument):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                InfrastructureBaseDocument
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['infrastructure_base_document'] = \
                infrastructure_base_document
            return self.call_with_http_info(**kwargs)

        self.put_infrastructure_base = _Endpoint(
            settings={
                'response_type': (InfrastructureBaseDocument,),
                'auth': [],
                'endpoint_path': '/infrastructure_base',
                'operation_id': 'put_infrastructure_base',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'infrastructure_base_document',
                ],
                'required': [
                    'infrastructure_base_document',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'infrastructure_base_document':
                        (InfrastructureBaseDocument,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'infrastructure_base_document': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__put_infrastructure_base
        )



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from stackl_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from stackl_client.model.functional_requirement import FunctionalRequirement
from stackl_client.model.http_validation_error import HTTPValidationError
from stackl_client.model.host_target import HostTarget
from stackl_client.model.infrastructure_base_document import InfrastructureBaseDocument
from stackl_client.model.infrastructure_target import InfrastructureTarget
from stackl_client.model.invocation import Invocation
from stackl_client.model.outputs_update import OutputsUpdate
from stackl_client.model.policy_template import PolicyTemplate
from stackl_client.model.service import Service
from stackl_client.model.service_policy_description import ServicePolicyDescription
from stackl_client.model.snapshot import Snapshot
from stackl_client.model.stack_application_template import StackApplicationTemplate
from stackl_client.model.stack_application_template_service import StackApplicationTemplateService
from stackl_client.model.stack_infrastructure_target import StackInfrastructureTarget
from stackl_client.model.stack_infrastructure_template import StackInfrastructureTemplate
from stackl_client.model.stack_instance import StackInstance
from stackl_client.model.stack_instance_invocation import StackInstanceInvocation
from stackl_client.model.stack_instance_service import StackInstanceService
from stackl_client.model.stack_instance_status import StackInstanceStatus
from stackl_client.model.stack_instance_update import StackInstanceUpdate
from stackl_client.model.stack_stage import StackStage
from stackl_client.model.validation_error import ValidationError




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.about_api import AboutApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from stackl_client.api.about_api import AboutApi
from stackl_client.api.functional_requirements_api import FunctionalRequirementsApi
from stackl_client.api.infrastructure_base_api import InfrastructureBaseApi
from stackl_client.api.outputs_api import OutputsApi
from stackl_client.api.policy_templates_api import PolicyTemplatesApi
from stackl_client.api.services_api import ServicesApi
from stackl_client.api.snapshots_api import SnapshotsApi
from stackl_client.api.stack_application_templates_api import StackApplicationTemplatesApi
from stackl_client.api.stack_infrastructure_templates_api import StackInfrastructureTemplatesApi
from stackl_client.api.stack_instances_api import StackInstancesApi



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.stack_instances_api import StackInstancesApi  # noqa: E501


class TestStackInstancesApi(unittest.TestCase):
    """StackInstancesApi unit test stubs"""

    def setUp(self):
        self.api = StackInstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_stack_instance(self):
        """Test case for delete_stack_instance

        Delete Stack Instance  # noqa: E501
        """
        pass

    def test_get_stack_instance(self):
        """Test case for get_stack_instance

        Get Stack Instance  # noqa: E501
        """
        pass

    def test_get_stack_instances(self):
        """Test case for get_stack_instances

        Get Stack Instances  # noqa: E501
        """
        pass

    def test_post_stack_instance(self):
        """Test case for post_stack_instance

        Post Stack Instance  # noqa: E501
        """
        pass

    def test_put_stack_instance(self):
        """Test case for put_stack_instance

        Put Stack Instance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


__version__ = "v0.5.0"

# import ApiClient
from stackl_client.api_client import ApiClient

# import Configuration
from stackl_client.configuration import Configuration

# import exceptions
from stackl_client.exceptions import OpenApiException
from stackl_client.exceptions import ApiAttributeError
from stackl_client.exceptions import ApiTypeError
from stackl_client.exceptions import ApiValueError
from stackl_client.exceptions import ApiKeyError
from stackl_client.exceptions import ApiException



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import stackl_client
from stackl_client.model.host_target import HostTarget
from stackl_client.model.stack_instance_service import StackInstanceService
from stackl_client.model.stack_instance_status import StackInstanceStatus
from stackl_client.model.stack_stage import StackStage
globals()['HostTarget'] = HostTarget
globals()['StackInstanceService'] = StackInstanceService
globals()['StackInstanceStatus'] = StackInstanceStatus
globals()['StackStage'] = StackStage
from stackl_client.model.stack_instance import StackInstance


class TestStackInstance(unittest.TestCase):
    """StackInstance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStackInstance(self):
        """Test StackInstance"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StackInstance()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.infrastructure_base_api import InfrastructureBaseApi  # noqa: E501


class TestInfrastructureBaseApi(unittest.TestCase):
    """InfrastructureBaseApi unit test stubs"""

    def setUp(self):
        self.api = InfrastructureBaseApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_infrastructure_base(self):
        """Test case for delete_infrastructure_base

        Delete Infrastructure Base  # noqa: E501
        """
        pass

    def test_get_infrastructure_base_by_type(self):
        """Test case for get_infrastructure_base_by_type

        Get Infrastructure Base By Type  # noqa: E501
        """
        pass

    def test_get_infrastructure_base_by_type_and_name(self):
        """Test case for get_infrastructure_base_by_type_and_name

        Get Infrastructure Base By Type And Name  # noqa: E501
        """
        pass

    def test_post_infrastructure_base(self):
        """Test case for post_infrastructure_base

        Post Infrastructure Base  # noqa: E501
        """
        pass

    def test_put_infrastructure_base(self):
        """Test case for put_infrastructure_base

        Put Infrastructure Base  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.outputs_api import OutputsApi  # noqa: E501


class TestOutputsApi(unittest.TestCase):
    """OutputsApi unit test stubs"""

    def setUp(self):
        self.api = OutputsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_outputs(self):
        """Test case for add_outputs

        Add Outputs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.stack_infrastructure_templates_api import StackInfrastructureTemplatesApi  # noqa: E501


class TestStackInfrastructureTemplatesApi(unittest.TestCase):
    """StackInfrastructureTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = StackInfrastructureTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_stack_infrastructure_template(self):
        """Test case for delete_stack_infrastructure_template

        Delete Stack Infrastructure Template  # noqa: E501
        """
        pass

    def test_get_stack_infrastructure_template_by_name(self):
        """Test case for get_stack_infrastructure_template_by_name

        Get Stack Infrastructure Template By Name  # noqa: E501
        """
        pass

    def test_get_stack_infrastructure_templates(self):
        """Test case for get_stack_infrastructure_templates

        Get Stack Infrastructure Templates  # noqa: E501
        """
        pass

    def test_post_stack_infrastructure_template(self):
        """Test case for post_stack_infrastructure_template

        Post Stack Infrastructure Template  # noqa: E501
        """
        pass

    def test_put_stack_infrastructure_template(self):
        """Test case for put_stack_infrastructure_template

        Put Stack Infrastructure Template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import unittest

import stackl_client
from stackl_client.api.snapshots_api import SnapshotsApi  # noqa: E501


class TestSnapshotsApi(unittest.TestCase):
    """SnapshotsApi unit test stubs"""

    def setUp(self):
        self.api = SnapshotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_snapshot(self):
        """Test case for create_snapshot

        Create Snapshot  # noqa: E501
        """
        pass

    def test_delete_snapshot(self):
        """Test case for delete_snapshot

        Delete Snapshot  # noqa: E501
        """
        pass

    def test_get_snapshot(self):
        """Test case for get_snapshot

        Get Snapshot  # noqa: E501
        """
        pass

    def test_get_snapshots(self):
        """Test case for get_snapshots

        Get Snapshots  # noqa: E501
        """
        pass

    def test_restore_latest_snapshot(self):
        """Test case for restore_latest_snapshot

        Restore Latest Snapshot  # noqa: E501
        """
        pass

    def test_restore_snapshot(self):
        """Test case for restore_snapshot

        Restore Snapshot  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.3.4.dev0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import stackl_client
from stackl_client.model.stack_application_template_service import StackApplicationTemplateService
from stackl_client.model.stack_stage import StackStage
globals()['StackApplicationTemplateService'] = StackApplicationTemplateService
globals()['StackStage'] = StackStage
from stackl_client.model.stack_instance_invocation import StackInstanceInvocation


class TestStackInstanceInvocation(unittest.TestCase):
    """StackInstanceInvocation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStackInstanceInvocation(self):
        """Test StackInstanceInvocation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StackInstanceInvocation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
